@@ -126,7 +126,7 @@ bb_barchart <- function(bb, data, mapping = NULL, stacked = FALSE, rotated = FAL
   } else {
     
     json <- bbmapping(data = data, mapping = mapping)
-    x <- as.character(mapping$x)
+    x <- as_label(mapping$x)
     names(json)[which(names(json) == x)] <- getOption("billboarder-x", default = "bb-x")
     
     if (is.null(mapping$group)) {
@@ -296,6 +296,7 @@ bb_categories <- function(bb, categories) {
 #' @param data A \code{data.frame}
 #' @param mapping Mapping of variables on the chart, see \code{\link{bbaes}}.
 #' @param ... Alternative mapping, you can specify \code{x = "Sepal.Length"} for example.
+#' @param point_opacity Opacity for points, value between \code{[0,1]}.
 #' 
 #' @note This function can be used with \code{\link{billboarderProxy}} in shiny application.
 #'
@@ -338,13 +339,12 @@ bb_categories <- function(bb, categories) {
 #'   ) %>% 
 #'   bb_x_axis(tick = list(fit = FALSE))
 #'
-bb_scatterplot <- function(bb, data, mapping = NULL, ...) {
+bb_scatterplot <- function(bb, data, mapping = NULL, ..., point_opacity = NULL) {
   
   if (missing(data))
     data <- bb$x$data
   
   args <- list(...)
-  
   mapping <- mapping %||% bb$x$mapping
   
   if (is.null(mapping)) {
@@ -353,15 +353,18 @@ bb_scatterplot <- function(bb, data, mapping = NULL, ...) {
     z <- args$z
     group <- args$group
   } else {
-    x <- as.character(mapping$x)
-    y <- as.character(mapping$y)
+    data <- lapply(mapping, rlang::eval_tidy, data = data)
+    nms <- lapply(mapping, rlang::as_label)
+    names(data) <- unlist(nms, use.names = FALSE)
+    x <- nms$x
+    y <- nms$y
     if (!is.null(mapping$group)) {
-      group <- as.character(mapping$group)
+      group <- nms$group
     } else {
       group <- NULL
     }
     if (!is.null(mapping$size)) {
-      z <- as.character(mapping$size)
+      z <- nms$size
     } else {
       z <- NULL
     }
@@ -369,7 +372,7 @@ bb_scatterplot <- function(bb, data, mapping = NULL, ...) {
   
   if (is.null(group)) {
     xs <- stats::setNames(list(x), y)
-    json <- as.list(data[, c(x, y)])
+    json <- data[c(x, y)]
     if (!is.null(z)) {
       json$y <- mapply(
         FUN = function(y, z) list(y = y, z = z), 
@@ -401,7 +404,6 @@ bb_scatterplot <- function(bb, data, mapping = NULL, ...) {
       )
     }
   }
-
   
   data_opt <- list(
     xs = xs,
@@ -422,25 +424,19 @@ bb_scatterplot <- function(bb, data, mapping = NULL, ...) {
     )
   )
   
-  
   if ("billboarder_Proxy" %in% class(bb)) {
-    
     bb <- bb_load(proxy = bb, json = json, xs = xs, unload = bb$unload) 
-    
     bb <- bb_proxy_axis_labels(proxy = bb, x = x, y = y)
-    
   } else {
-    
     bb <- .bb_opt2(bb, "data", data_opt)
-    
     bb <- .bb_opt(bb, "legend", show = !is.null(group))
-    
     bb <- .bb_opt2(bb, "axis", data_axis)
-    
     if (!is.null(z)) {
       bb <- .bb_opt2(bb, "axis", list(x = list(padding = list(right = 0.1))))
     }
-    
+    if (!is.null(point_opacity)) {
+      bb <- bb_add_style(bb, ".bb-circles circle" = sprintf("opacity: %s !important;", point_opacity))
+    }
   }
   
   return(bb)
@@ -1003,13 +999,13 @@ bb_densityplot <- function(bb, data, mapping = NULL, stacked = FALSE, stat = "de
   } else {
     if (!is.null(mapping)) {
       if (!is.null(mapping$group))
-        group <- as.character(mapping$group)
+        group <- as_label(mapping$group)
       else
         group <- NULL
       mapping$group <- NULL
       data_mapped <- bbmapping(data = data, mapping = mapping)
       data_mapped <- data.frame(unlist(data_mapped))
-      names(data_mapped) <- as.character(mapping$x)
+      names(data_mapped) <- as_label(mapping$x)
       if (!is.null(group))
         data_mapped[[group]] <- data[[group]]
       data <- data_mapped
@@ -1228,13 +1224,13 @@ bb_histogram <- function(bb, data, mapping = NULL, stacked = FALSE, fill = FALSE
   } else {
     if (!is.null(mapping)) {
       if (!is.null(mapping$group))
-        group <- as.character(mapping$group)
+        group <- as_label(mapping$group)
       else
         group <- NULL
       mapping$group <- NULL
       data_mapped <- bbmapping(data = data, mapping = mapping)
       data_mapped <- data.frame(unlist(data_mapped))
-      names(data_mapped) <- as.character(mapping$x)
+      names(data_mapped) <- as_label(mapping$x)
       if (!is.null(group))
         data_mapped[[group]] <- data[[group]]
       data <- data_mapped
@@ -1329,8 +1325,6 @@ bb_histogram <- function(bb, data, mapping = NULL, stacked = FALSE, fill = FALSE
     )
   )
   
-  
-  
   # tooltip
   if (is.null(binwidth)) {
     binwidth <- dat$xmax[1] - dat$xmin[1]
@@ -1351,12 +1345,10 @@ bb_histogram <- function(bb, data, mapping = NULL, stacked = FALSE, fill = FALSE
   } else {
     
     bb <- .bb_opt2(bb, "data", data_opt)
-    
     bb <- .bb_opt(bb, "legend", show = !is.null(group))
-    
     bb <- .bb_opt2(bb, "axis", axis_opt)
-    
     bb <- .bb_opt2(bb, "tooltip", tooltip_opt)
+    bb <- .bb_opt(bb, "point", show = FALSE)
     
   }
   
@@ -1434,8 +1426,8 @@ bb_lollipop <- function(bb, data, mapping = NULL, rotated = FALSE, point_color =
   
   
   if (!is.null(mapping)) {
-    x <- as.character(mapping$x)
-    y <- as.character(mapping$y)
+    x <- as_label(mapping$x)
+    y <- as_label(mapping$y)
     json <- bbmapping(data = data, mapping = mapping)
   } else {
     x <- names(data)[1]
@@ -1563,7 +1555,7 @@ bb_radarchart <- function(bb, data, mapping = NULL, ...) {
   } else {
     
     json <- bbmapping(data = data, mapping = mapping)
-    x <- as.character(mapping$x)
+    x <- as_label(mapping$x)
     names(json)[which(names(json) == x)] <- getOption("billboarder-x", default = "bb-x")
     
   }
